#!/bin/sh
CCAFE_CONFIG=/usr/bin/ccafe-config
CCAFE_CLIENT=`$CCAFE_CONFIG --var CCAFE_CLIENT`
PROGNAME=$0
OTHERARG=""
PKGDATADIR=`$CCAFE_CONFIG --var CCAFE_pkgdatadir`
DEFAULT_RC=$PKGDATADIR/CcaffeineRC
CCAFE_RC=$DEFAULT_RC
CCAFE_IO="--ccafe-io2tty"
KILL_LIST="ccafe-client java mpirun"
PORT="NO PORT GIVEN"
DEBUG=0
# process the command line stuff before validating io locations
i=$#
while [ $i -gt 0 ]
do
	i=`expr $i - 1`
	arg=$1
	case $arg in

	"--help")
		cat << __EOF 
$0 --port <port> [options]

	--kill  		crudely wipe out the Ccaffeine frontend/backend
				run previously. 


        --debug         [0,1]   be less or more verbose in launching.


	--help  		this message.


	ccaffeine options	any valid combination of ccafe-client options
          Interesting ones are:


	--port <port number> (required)

	  A free port for which this program will be the server. Note
	  that this must match the "--port" param given to the
	  "gui.sh" command.  Generally any port number that is above
	  1024 and not in use already is good to try.  If you get the
	  error:

ClientServerSocket::acceptConnections: Address already in use

	    you have chosen unwisely, try a different one: 2470, 4724,
	    last four digits of your social security number, whatever.


          --ccafe-rc <input script> 

	    "RC" file to identify and preload components into the palette.
            Default is:  $DEFAULT_RC


	  --ccafe-outputdir <directory for debug IO> 

            Within this directory will appear output files from stderr
            and stdout for all parallel processes.  This includes the
            debug messages from Ccaffeine itself.  Default is to send
            it to the the terminal.

__EOF
		exit 0
		;;

	"--kill")
		killall $KILL_LIST >/dev/null 2>&1
		sleep 2
		killall -9 $KILL_LIST >/dev/null 2>&1
		exit 0
		;;

	"--port")
		shift
		PORT=$1
		;;


	"--builderPort")
		shift
		PORT=$1
		;;


        "--debug")
                shift
                DEBUG="$1"
                ;;

        "--ccafe-rc")
                shift
                CCAFE_RC="$1"
                ;;


	"--ccafe-outputdir")
		shift
		CCAFE_IO="--ccafe-outputdir $1"
		;;

	*)
		OTHERARG="$OTHERARG $arg"
		if [ $DEBUG -ne "0" ]
		then
		    echo "arg =" $arg
		    echo "OTHERARG = " $OTHERARG
		fi
	        ;;
        esac
	if [ $# -gt 0 ]; then
		shift
	fi
	i=$#
done


if [ "$PORT" = "NO PORT GIVEN" ]; 
then
    echo "No --port switch was given.  This is required for this application."
    echo "The port number given here must match the port given to the GUI"
    echo "If you are not sure try some of these numbers: 3645,2470,8211"
    echo "Any number above 1024 and lower than 0xffff that doesn't collide with something already using it will do."
    exit 0
fi

$CCAFE_CLIENT --type server $CCAFE_IO --port $PORT --ccafe-rc $CCAFE_RC

