#!/bin/sh
INSTALLATION=/usr
CCAFE_CONFIG=/usr/bin/ccafe-config
OTHERARG=""
KILL_LIST="ccafe-client java mpirun"
BABEL_CONFIG="`$CCAFE_CONFIG --var CCAFE_BABEL_ROOT`/bin/babel-config"
JAVA="`$BABEL_CONFIG --query-var=WHICH_JAVA`"
HOST=127.0.0.1
PORT="NO PORT GIVEN"
KILL=no
# process the command line stuff before validating io locations
i=$#
while [ $i -gt 0 ]
do
	arg=$1
	case $arg in

	"--help")
		cat << __EOF 
$0 --port <port> [options]

	--kill  	crudely wipe out the Ccaffeine frontend/backend
			run previously. Kills everything matching 
			kill -9 $KILL_LIST, which is rather draconian.


        --debug         [0,1]   be less or more verbose in launching.


	--help  		this message.


	--builderPort <port number>  same as --port


	--port <port number> (required)

	  A free port for which this program will be the client. Note
	  that this must match the "--port" param given to the
	  "gui-backend.sh" command and the gui-backend.sh server
	  *must* be started first for this program to have something
	  to connect to.  If you get a "connection refused" message,
	  it means that there is nothing seriving the port you have
	  chosen. If you get:

Exception in RemoteServer:java.net.ConnectException: Connection refused

	  Then there is nothing listening to that socket.


__EOF
		exit 0
		;;

	"--kill")
		KILL=yes
		;;

	"--port")
		shift
		PORT=$1
		;;

	"--builderPort")
		shift
		PORT=$1
		;;

	"--host")
		shift
		HOST="$1"
		;;

        "--debug")
                shift
                DEBUG="$1"
                ;;

	*)
		OTHERARG="$OTHERARG $arg"
		if ! [ "x$DEBUG" = "x0" ] ; then
		    echo "arg =" $arg
		    echo "OTHERARG = " $OTHERARG
		fi
	        ;;
        esac
	if [ $# -gt 0 ]; then
		shift
	fi
	i=$#
done

if [ "x$KILL" = "xyes" ]; then
	killall $KILL_LIST >/dev/null 2>&1
	sleep 2
	killall -9 $KILL_LIST >/dev/null 2>&1
	exit 0
fi

if [ "x$PORT" = "xNO PORT GIVEN" ]; then
    echo "No --port switch was given.  This is required for this application."
    echo "The port number given here must match the port given to the GUI"
    echo "If you are not sure try some of these numbers: 3645,2470,8211"
    echo "Any number above 1024 and lower than 0xffff that doesn't collide with something already using it will do."
    exit 0
fi

if [ "x$DEBUG" = "x1" ] ; then
echo Command to launch the gui follows:
echo java -classpath /usr/share/java/ccafe-gui.jar gov.sandia.ccaffeine.dc.user_iface.BuilderClient --builderPort $PORT --host $HOST $OTHERARG
fi

java -classpath /usr/share/java/ccafe-gui.jar gov.sandia.ccaffeine.dc.user_iface.BuilderClient --builderPort $PORT --host $HOST $OTHERARG

